@@ -2,6 +2,8 @@ pub mod api_token;
 pub use self::api_token::ApiToken;
 pub mod auth_methods;
 pub use self::auth_methods::AuthMethods;
+pub mod dns;
+pub use self::dns::Dns;
 pub mod invite_status;
 pub use self::invite_status::InviteStatus;
 pub mod ip_range;
@@ -18,8 +20,6 @@ pub mod network;
 pub use self::network::Network;
 pub mod network_config;
 pub use self::network_config::NetworkConfig;
-pub mod network_config_dns;
-pub use self::network_config_dns::NetworkConfigDns;
 pub mod organization;
 pub use self::organization::Organization;
 pub mod organization_invitation;
